@@ -3,9 +3,10 @@
 import argparse
 from multiprocessing.connection import Client, Listener
 
-import notify3
 from gi.repository import GLib
 
+from .notify3 import notify3
+
 notify2 = notify3
 
 def clean_up_text(text):
